changeset 8584:058efd3cb86f

[gaim-migrate @ 9334] " This is definitely not the most critical fix, but every time i see the text "catagory" my eyes bleed a little bit. This should remedy this unnecessary loss of blood - hopefully this way i can make my visits to the Red Cross more frequent." --Daniel Atallah committer: Tailor Script <tailor@pidgin.im>
author Luke Schierer <lschiere@pidgin.im>
date Mon, 05 Apr 2004 17:33:34 +0000
parents fc27237783ee
children e4087b5c0627
files src/gtkroomlist.c src/protocols/yahoo/yahoo.c src/protocols/yahoo/yahoochat.c src/protocols/yahoo/yahoochat.h src/prpl.h src/roomlist.c src/roomlist.h
diffstat 7 files changed, 29 insertions(+), 29 deletions(-) [+]
line wrap: on
line diff
--- a/src/gtkroomlist.c	Mon Apr 05 07:11:24 2004 +0000
+++ b/src/gtkroomlist.c	Mon Apr 05 17:33:34 2004 +0000
@@ -271,15 +271,15 @@
 static void row_expanded_cb(GtkTreeView *treeview, GtkTreeIter *arg1, GtkTreePath *arg2, gpointer user_data)
 {
 	GaimRoomlist *list = user_data;
-	GaimRoomlistRoom *catagory;
+	GaimRoomlistRoom *category;
 	GValue val = { 0, };
 
 	gtk_tree_model_get_value(gtk_tree_view_get_model(treeview), arg1, ROOM_COLUMN, &val);
-	catagory = g_value_get_pointer(&val);
+	category = g_value_get_pointer(&val);
 
-	if (!catagory->expanded_once) {
-		gaim_roomlist_expand_catagory(list, catagory);
-		catagory->expanded_once = TRUE;
+	if (!category->expanded_once) {
+		gaim_roomlist_expand_category(list, category);
+		category->expanded_once = TRUE;
 	}
 }
 
@@ -657,12 +657,12 @@
 	else
 		iter = child;
 
-	if (room->type & GAIM_ROOMLIST_ROOMTYPE_CATAGORY)
+	if (room->type & GAIM_ROOMLIST_ROOMTYPE_CATEGORY)
 		gtk_tree_store_append(rl->model, &child, &iter);
 
 	path = gtk_tree_model_get_path(GTK_TREE_MODEL(rl->model), &iter);
 
-	if (room->type & GAIM_ROOMLIST_ROOMTYPE_CATAGORY) {
+	if (room->type & GAIM_ROOMLIST_ROOMTYPE_CATEGORY) {
 		rr = gtk_tree_row_reference_new(GTK_TREE_MODEL(rl->model), path);
 		g_hash_table_insert(rl->cats, room, rr);
 	}
--- a/src/protocols/yahoo/yahoo.c	Mon Apr 05 07:11:24 2004 +0000
+++ b/src/protocols/yahoo/yahoo.c	Mon Apr 05 17:33:34 2004 +0000
@@ -3274,7 +3274,7 @@
 	NULL,
 	yahoo_roomlist_get_list,
 	yahoo_roomlist_cancel,
-	yahoo_roomlist_expand_catagory,
+	yahoo_roomlist_expand_category,
 };
 
 static GaimPluginInfo info =
--- a/src/protocols/yahoo/yahoochat.c	Mon Apr 05 07:11:24 2004 +0000
+++ b/src/protocols/yahoo/yahoochat.c	Mon Apr 05 17:33:34 2004 +0000
@@ -1127,7 +1127,7 @@
 			return;
 
 		parent = g_queue_peek_head(s->q);
-		r = gaim_roomlist_room_new(GAIM_ROOMLIST_ROOMTYPE_CATAGORY, name, parent);
+		r = gaim_roomlist_room_new(GAIM_ROOMLIST_ROOMTYPE_CATEGORY, name, parent);
 		gaim_roomlist_room_add_field(list, r, (gpointer)name);
 		gaim_roomlist_room_add_field(list, r, (gpointer)id);
 		gaim_roomlist_room_add(list, r);
@@ -1188,10 +1188,10 @@
 		GaimRoomlistRoom *r, *l;
 
 		if (s->room.type == yrt_yahoo)
-			r = gaim_roomlist_room_new(GAIM_ROOMLIST_ROOMTYPE_CATAGORY|GAIM_ROOMLIST_ROOMTYPE_ROOM,
+			r = gaim_roomlist_room_new(GAIM_ROOMLIST_ROOMTYPE_CATEGORY|GAIM_ROOMLIST_ROOMTYPE_ROOM,
 		                                   s->room.name, s->yrl->cat);
 		else
-			r = gaim_roomlist_room_new(GAIM_ROOMLIST_ROOMTYPE_CATAGORY|GAIM_ROOMLIST_ROOMTYPE_ROOM,
+			r = gaim_roomlist_room_new(GAIM_ROOMLIST_ROOMTYPE_CATEGORY|GAIM_ROOMLIST_ROOMTYPE_ROOM,
 		                                   s->room.name, s->yrl->ucat);
 
 		gaim_roomlist_room_add_field(s->list, r, s->room.name);
@@ -1384,16 +1384,16 @@
 	g_list_free(k);
 }
 
-void yahoo_roomlist_expand_catagory(GaimRoomlist *list, GaimRoomlistRoom *catagory)
+void yahoo_roomlist_expand_category(GaimRoomlist *list, GaimRoomlistRoom *category)
 {
 	struct yahoo_roomlist *yrl;
 	char *url;
 	char *id;
 
-	if (catagory->type != GAIM_ROOMLIST_ROOMTYPE_CATAGORY)
+	if (category->type != GAIM_ROOMLIST_ROOMTYPE_CATEGORY)
 		return;
 
-	if (!(id = g_list_nth_data(catagory->fields, 1))) {
+	if (!(id = g_list_nth_data(category->fields, 1))) {
 		gaim_roomlist_set_in_progress(list, FALSE);
 		return;
 	}
@@ -1405,13 +1405,13 @@
 
 	yrl = g_new0(struct yahoo_roomlist, 1);
 	yrl->list = list;
-	yrl->cat = catagory;
+	yrl->cat = category;
 	list->proto_data = g_list_append(list->proto_data, yrl);
 
 	gaim_url_parse(url, &(yrl->host), NULL, &(yrl->path));
 	g_free(url);
 
-	yrl->ucat = gaim_roomlist_room_new(GAIM_ROOMLIST_ROOMTYPE_CATAGORY, _("User Rooms"), yrl->cat);
+	yrl->ucat = gaim_roomlist_room_new(GAIM_ROOMLIST_ROOMTYPE_CATEGORY, _("User Rooms"), yrl->cat);
 	gaim_roomlist_room_add(list, yrl->ucat);
 
 	if (gaim_proxy_connect(list->account,
--- a/src/protocols/yahoo/yahoochat.h	Mon Apr 05 07:11:24 2004 +0000
+++ b/src/protocols/yahoo/yahoochat.h	Mon Apr 05 17:33:34 2004 +0000
@@ -52,6 +52,6 @@
 /* room listing functions */
 GaimRoomlist *yahoo_roomlist_get_list(GaimConnection *gc);
 void yahoo_roomlist_cancel(GaimRoomlist *list);
-void yahoo_roomlist_expand_catagory(GaimRoomlist *list, GaimRoomlistRoom *catagory);
+void yahoo_roomlist_expand_category(GaimRoomlist *list, GaimRoomlistRoom *category);
 
 #endif /* _YAHOO_CHAT_H_ */
--- a/src/prpl.h	Mon Apr 05 07:11:24 2004 +0000
+++ b/src/prpl.h	Mon Apr 05 17:33:34 2004 +0000
@@ -327,7 +327,7 @@
 	/* room listing prpl callbacks */
 	struct _GaimRoomlist *(*roomlist_get_list)(GaimConnection *gc);
 	void (*roomlist_cancel)(struct _GaimRoomlist *list);
-	void (*roomlist_expand_catagory)(struct _GaimRoomlist *list, struct _GaimRoomlistRoom *catagory);
+	void (*roomlist_expand_category)(struct _GaimRoomlist *list, struct _GaimRoomlistRoom *category);
 
 };
 
--- a/src/roomlist.c	Mon Apr 05 07:11:24 2004 +0000
+++ b/src/roomlist.c	Mon Apr 05 17:33:34 2004 +0000
@@ -216,14 +216,14 @@
 		prpl_info->roomlist_cancel(list);
 }
 
-void gaim_roomlist_expand_catagory(GaimRoomlist *list, GaimRoomlistRoom *catagory)
+void gaim_roomlist_expand_category(GaimRoomlist *list, GaimRoomlistRoom *category)
 {
 	GaimPluginProtocolInfo *prpl_info = NULL;
 	GaimConnection *gc;
 
 	g_return_if_fail(list != NULL);
-	g_return_if_fail(catagory != NULL);
-	g_return_if_fail(catagory->type & GAIM_ROOMLIST_ROOMTYPE_CATAGORY);
+	g_return_if_fail(category != NULL);
+	g_return_if_fail(category->type & GAIM_ROOMLIST_ROOMTYPE_CATEGORY);
 
 	gc = gaim_account_get_connection(list->account);
 	g_return_if_fail(gc != NULL);
@@ -231,8 +231,8 @@
 	if (gc->prpl != NULL)
 		prpl_info = GAIM_PLUGIN_PROTOCOL_INFO(gc->prpl);
 
-	if (prpl_info && prpl_info->roomlist_expand_catagory)
-		prpl_info->roomlist_expand_catagory(list, catagory);
+	if (prpl_info && prpl_info->roomlist_expand_category)
+		prpl_info->roomlist_expand_category(list, category);
 }
 
 /*@}*/
--- a/src/roomlist.h	Mon Apr 05 07:11:24 2004 +0000
+++ b/src/roomlist.h	Mon Apr 05 17:33:34 2004 +0000
@@ -56,7 +56,7 @@
  * These are ORable flags.
  */
 enum _GaimRoomlistRoomType {
-	GAIM_ROOMLIST_ROOMTYPE_CATAGORY = 0x01, /**< It's a catagory, but not a room you can join. */
+	GAIM_ROOMLIST_ROOMTYPE_CATEGORY = 0x01, /**< It's a category, but not a room you can join. */
 	GAIM_ROOMLIST_ROOMTYPE_ROOM = 0x02,     /**< It's a room, like the kind you can join. */
 };
 
@@ -222,17 +222,17 @@
 void gaim_roomlist_cancel_get_list(GaimRoomlist *list);
 
 /**
  * Tells the prpl that a catagory was expanded.
  *
  * On some protocols, the rooms in the catagory
  * won't be fetched until this is called.
  *
  * @param list The room list.
  * @param room The catagory that was expanded. The expression
  *             (catagory->type & GAIM_ROOMLIST_ROOMTYPE_CATAGORY)
  *             must be true.
  */
-void gaim_roomlist_expand_catagory(GaimRoomlist *list, GaimRoomlistRoom *catagory);
+void gaim_roomlist_expand_category(GaimRoomlist *list, GaimRoomlistRoom *category);
 
 /*@}*/
@@ -222,17 +222,17 @@
 
 /**
- * Tells the prpl that a catagory was expanded.
+ * Tells the prpl that a category was expanded.
  *
@@ -222,17 +222,17 @@
  *
- * On some protocols, the rooms in the catagory
+ * On some protocols, the rooms in the category
  * won't be fetched until this is called.
  *
@@ -222,17 +222,17 @@
  *
  * @param list The room list.
- * @param room The catagory that was expanded. The expression
- *             (catagory->type & GAIM_ROOMLIST_ROOMTYPE_CATAGORY)
+ * @param room The category that was expanded. The expression
+ *             (category->type & GAIM_ROOMLIST_ROOMTYPE_CATEGORY)
  *             must be true.
  */